@@ -6,8 +6,8 @@
 #include "ephy-widgets-type-builtins.h"
 
 
-/* enumerations from "/usr/src/ports/epiphany/epiphany-3.8.2-2.i686/src/epiphany-3.8.2/lib/widgets/ephy-removable-pixbuf-renderer.h" */
-#include "/usr/src/ports/epiphany/epiphany-3.8.2-2.i686/src/epiphany-3.8.2/lib/widgets/ephy-removable-pixbuf-renderer.h"
+/* enumerations from "/usr/src/ports/epiphany/epiphany-3.8.2-3.x86_64/src/epiphany-3.8.2/lib/widgets/ephy-removable-pixbuf-renderer.h" */
+#include "/usr/src/ports/epiphany/epiphany-3.8.2-3.x86_64/src/epiphany-3.8.2/lib/widgets/ephy-removable-pixbuf-renderer.h"
 GType
 ephy_removable_pixbuf_render_policy_get_type (void)
 {
